@@ -597,9 +597,12 @@ class Logger:
             self.last_msg_was_job_info = False
 
 
-def format_dict(dict_like, omit_keys=[], omit_values=[]):
+def format_dict(dict_like, omit_keys=None, omit_values=None):
     from snakemake.io import Namedlist
 
+    omit_keys = omit_keys or []
+    omit_values = omit_values or []
+
     if isinstance(dict_like, Namedlist):
         items = dict_like.items()
     elif isinstance(dict_like, dict):
